aboutsummaryrefslogtreecommitdiff
path: root/google/ads/googleads/v2/resources/parental_status_view.proto
diff options
context:
space:
mode:
Diffstat (limited to 'google/ads/googleads/v2/resources/parental_status_view.proto')
-rw-r--r--google/ads/googleads/v2/resources/parental_status_view.proto4
1 files changed, 2 insertions, 2 deletions
diff --git a/google/ads/googleads/v2/resources/parental_status_view.proto b/google/ads/googleads/v2/resources/parental_status_view.proto
index 6aed3027b..7f4d36bc2 100644
--- a/google/ads/googleads/v2/resources/parental_status_view.proto
+++ b/google/ads/googleads/v2/resources/parental_status_view.proto
@@ -38,12 +38,12 @@ message ParentalStatusView {
pattern: "customers/{customer}/parentalStatusViews/{parental_status_view}"
};
// Immutable. The resource name of the parental status view.
// Parental Status view resource names have the form:
//
// `customers/{customer_id}/parentalStatusViews/{ad_group_id}~{criterion_id}`
string resource_name = 1 [
- (google.api.field_behavior) = IMMUTABLE,
+ (google.api.field_behavior) = OUTPUT_ONLY,
(google.api.resource_reference) = {
type: "googleads.googleapis.com/ParentalStatusView"
}
@@ -38,12 +38,12 @@ message ParentalStatusView {
pattern: "customers/{customer}/parentalStatusViews/{parental_status_view}"
};
- // Immutable. The resource name of the parental status view.
+ // Output only. The resource name of the parental status view.
// Parental Status view resource names have the form:
//